From 82ac40700830c7d4cc1c07932529935de36b7f95 Mon Sep 17 00:00:00 2001
From: Peter Smith <peter.b.smith@fujitsu.com>
Date: Wed, 8 Dec 2021 17:50:46 +1100
Subject: [PATCH v1] Fix typos for "an" versus "a".

---
 configure                                       | 2 +-
 contrib/amcheck/verify_nbtree.c                 | 2 +-
 doc/src/sgml/ecpg.sgml                          | 2 +-
 src/backend/access/table/toast_helper.c         | 2 +-
 src/backend/catalog/pg_depend.c                 | 2 +-
 src/backend/jit/llvm/llvmjit_error.cpp          | 2 +-
 src/backend/replication/logical/reorderbuffer.c | 6 +++---
 7 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/configure b/configure
index 5f842a8..912c552 100755
--- a/configure
+++ b/configure
@@ -4043,7 +4043,7 @@ do
 	   ac_cv_exeext=`expr "$ac_file" : '[^.]*\(\..*\)'`
 	fi
 	# We set ac_cv_exeext here because the later test for it is not
-	# safe: cross compilers may not add the suffix if given an `-o'
+	# safe: cross compilers may not add the suffix if given a `-o'
 	# argument, so we may need to know it at that point already.
 	# Even if this section looks crufty: it has the advantage of
 	# actually working.
diff --git a/contrib/amcheck/verify_nbtree.c b/contrib/amcheck/verify_nbtree.c
index dc1508b..d3b29d3 100644
--- a/contrib/amcheck/verify_nbtree.c
+++ b/contrib/amcheck/verify_nbtree.c
@@ -1512,7 +1512,7 @@ bt_target_page_check(BtreeCheckState *state)
 	/*
 	 * Special case bt_child_highkey_check() call
 	 *
-	 * We don't pass an real downlink, but we've to finish the level
+	 * We don't pass a real downlink, but we've to finish the level
 	 * processing. If condition is satisfied, we've already processed all the
 	 * downlinks from the target level.  But there still might be pages to the
 	 * right of the child page pointer to by our rightmost downlink.  And they
diff --git a/doc/src/sgml/ecpg.sgml b/doc/src/sgml/ecpg.sgml
index 04d4a6b..5a2dc4a 100644
--- a/doc/src/sgml/ecpg.sgml
+++ b/doc/src/sgml/ecpg.sgml
@@ -6977,7 +6977,7 @@ EXEC SQL CLOSE cursor_name;
     <title>Compatibility</title>
 
     <para>
-     <command>DECLARE STATEMENT</command> is a extension of the SQL standard,
+     <command>DECLARE STATEMENT</command> is an extension of the SQL standard,
      but can be used in famous DBMSs.
     </para>
    </refsect1>
diff --git a/src/backend/access/table/toast_helper.c b/src/backend/access/table/toast_helper.c
index 53f78f9..013236b 100644
--- a/src/backend/access/table/toast_helper.c
+++ b/src/backend/access/table/toast_helper.c
@@ -33,7 +33,7 @@
  * All of these arrays should have a length equal to tupleDesc->natts.
  *
  * On return, toast_flags and toast_attr will have been initialized.
- * toast_flags is just a single uint8, but toast_attr is an caller-provided
+ * toast_flags is just a single uint8, but toast_attr is a caller-provided
  * array with a length equal to tupleDesc->natts.  The caller need not
  * perform any initialization of the array before calling this function.
  */
diff --git a/src/backend/catalog/pg_depend.c b/src/backend/catalog/pg_depend.c
index 07bcdc4..5f37bf6 100644
--- a/src/backend/catalog/pg_depend.c
+++ b/src/backend/catalog/pg_depend.c
@@ -180,7 +180,7 @@ recordMultipleDependencies(const ObjectAddress *depender,
  * Passing false is a guarantee that the object is newly created, and so
  * could not already be a member of any extension.
  *
- * Note: isReplace = true is typically used when updating a object in
+ * Note: isReplace = true is typically used when updating an object in
  * CREATE OR REPLACE and similar commands.  The net effect is that if an
  * extension script uses such a command on a pre-existing free-standing
  * object, the object will be absorbed into the extension.  If the object
diff --git a/src/backend/jit/llvm/llvmjit_error.cpp b/src/backend/jit/llvm/llvmjit_error.cpp
index daefb3e..f472073 100644
--- a/src/backend/jit/llvm/llvmjit_error.cpp
+++ b/src/backend/jit/llvm/llvmjit_error.cpp
@@ -84,7 +84,7 @@ llvm_leave_fatal_on_oom(void)
 }
 
 /*
- * Are we currently in an fatal-on-oom section? Useful to skip cleanup in case
+ * Are we currently in a fatal-on-oom section? Useful to skip cleanup in case
  * of errors.
  */
 bool
diff --git a/src/backend/replication/logical/reorderbuffer.c b/src/backend/replication/logical/reorderbuffer.c
index 46e6660..7aa5647 100644
--- a/src/backend/replication/logical/reorderbuffer.c
+++ b/src/backend/replication/logical/reorderbuffer.c
@@ -452,7 +452,7 @@ ReorderBufferReturnTXN(ReorderBuffer *rb, ReorderBufferTXN *txn)
 }
 
 /*
- * Get an fresh ReorderBufferChange.
+ * Get a fresh ReorderBufferChange.
  */
 ReorderBufferChange *
 ReorderBufferGetChange(ReorderBuffer *rb)
@@ -558,7 +558,7 @@ ReorderBufferGetTupleBuf(ReorderBuffer *rb, Size tuple_len)
 }
 
 /*
- * Free an ReorderBufferTupleBuf.
+ * Free a ReorderBufferTupleBuf.
  */
 void
 ReorderBufferReturnTupleBuf(ReorderBuffer *rb, ReorderBufferTupleBuf *tuple)
@@ -639,7 +639,7 @@ ReorderBufferTXNByXid(ReorderBuffer *rb, TransactionId xid, bool create,
 	}
 
 	/*
-	 * If the cache wasn't hit or it yielded an "does-not-exist" and we want
+	 * If the cache wasn't hit or it yielded a "does-not-exist" and we want
 	 * to create an entry.
 	 */
 
-- 
1.8.3.1

